# About PISA

PISA implements a modular architecture wherein users can combine one or more analysis pipelines into distribution makers to make "data" and—separately—template distributions.
Within each pipeline, users can choose among several implementations for each of the stages they choose to include.
